@@ -131,6 +131,7 @@ public class ManifestPlugin extends BundlePlugin
         }
         catch ( IOException e )
         {
+            getLog().error( e.getLocalizedMessage() );
             throw new MojoExecutionException( "Error trying to generate Manifest", e );
         }
         catch ( MojoFailureException e )
@@ -428,15 +429,26 @@ public class ManifestPlugin extends BundlePlugin
             // generated last?
             Path cacheData = getIncrementalDataPath(project);
             if(!Files.isRegularFile(cacheData)) {
+                getLog().debug("No cache data file found at '" + cacheData + "', generating manifest.");
                 return false;
             }
             long manifestLastModified = lastModified(cacheData);
             while (project != null)
             {
-                Path pom = project.getFile().toPath();
-                if (manifestLastModified < lastModified(pom))
-                {
-                    return false;
+                if (project.getFile() != null) {
+                    Path pom = project.getFile().toPath();
+                    if (manifestLastModified < lastModified(pom))
+                    {
+                        getLog().debug("POM file at '" + pom + "' newer than cache data file, generating manifest.");
+                        return false;
+                    }
+                } else {
+                    if (project.getVersion().endsWith("-SNAPSHOT")) { // is it mutable?
+                        getLog().debug("POM file not accessible for SNAPSHOT project '" + project + "', assume modification.");
+                        return false;
+                    } else {
+                        getLog().debug("POM file not accessible for non-SNAPSHOT project '" + project + "', assume no modification.");
+                    }
                 }
                 project = project.getParent();
             }
