@@ -1,6 +1,10 @@
 package org.apache.felix.bundleplugin;
 
 
+import static org.hamcrest.CoreMatchers.containsString;
+import static org.hamcrest.CoreMatchers.not;
+import static org.hamcrest.MatcherAssert.assertThat;
+
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -22,6 +26,7 @@ package org.apache.felix.bundleplugin;
 
 import java.io.File;
 import java.io.FileOutputStream;
+import java.nio.charset.StandardCharsets;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.LinkedHashSet;
@@ -31,16 +36,16 @@ import java.util.Set;
 import java.util.TreeMap;
 import java.util.jar.Manifest;
 
+import org.apache.felix.bundleplugin.BundlePlugin.ClassPathItem;
 import org.apache.maven.model.Organization;
 import org.apache.maven.plugin.testing.stubs.MavenProjectStub;
 import org.apache.maven.project.MavenProject;
-import org.apache.maven.shared.dependency.graph.DependencyGraphBuilder;
-import org.apache.maven.shared.dependency.graph.DependencyNode;
 import org.osgi.framework.Constants;
 
 import aQute.bnd.osgi.Analyzer;
 import aQute.bnd.osgi.Builder;
 import aQute.bnd.osgi.Jar;
+import aQute.bnd.osgi.Resource;
 
 
 /**
@@ -61,7 +66,6 @@ public class BundlePluginTest extends AbstractBundlePluginTest
         plugin = new BundlePlugin();
         plugin.setBuildDirectory( "." );
         plugin.setOutputDirectory(new File(getBasedir(), "target" + File.separatorChar + "scratch"));
-        setVariableValueToObject(plugin, "m_dependencyGraphBuilder", lookup(DependencyGraphBuilder.class.getName(), "default"));
     }
 
 
@@ -236,8 +240,7 @@ public class BundlePluginTest extends AbstractBundlePluginTest
             + "*;classifier=;type=jar;scope=runtime" );
         Properties props = new Properties();
 
-        DependencyNode dependencyGraph = plugin.buildDependencyGraph(project);
-        Builder builder = plugin.buildOSGiBundle( project, dependencyGraph, instructions, props, plugin.getClasspath( project, dependencyGraph ) );
+        Builder builder = plugin.buildOSGiBundle( project, instructions, plugin.getClasspath( project) );
         Manifest manifest = builder.getJar().getManifest();
 
         String bcp = manifest.getMainAttributes().getValue( Constants.BUNDLE_CLASSPATH );
@@ -264,10 +267,8 @@ public class BundlePluginTest extends AbstractBundlePluginTest
 
         Map instructions = new HashMap();
         instructions.put( DependencyEmbedder.EMBED_DEPENDENCY, "!type=jar, !artifactId=c" );
-        Properties props = new Properties();
 
-        DependencyNode dependencyGraph = plugin.buildDependencyGraph(project);
-        Builder builder = plugin.buildOSGiBundle( project, dependencyGraph, instructions, props, plugin.getClasspath( project, dependencyGraph ) );
+        Builder builder = plugin.buildOSGiBundle( project, instructions, plugin.getClasspath( project) );
         Manifest manifest = builder.getJar().getManifest();
 
         String bcp = manifest.getMainAttributes().getValue( Constants.BUNDLE_CLASSPATH );
@@ -296,8 +297,7 @@ public class BundlePluginTest extends AbstractBundlePluginTest
         instructions.put( DependencyEmbedder.EMBED_DEPENDENCY, "c;type=jar,c;type=sources" );
         Properties props = new Properties();
 
-        DependencyNode dependencyGraph = plugin.buildDependencyGraph(project);
-        Builder builder = plugin.buildOSGiBundle( project, dependencyGraph, instructions, props, plugin.getClasspath( project, dependencyGraph ) );
+        Builder builder = plugin.buildOSGiBundle( project, instructions, plugin.getClasspath( project) );
         Manifest manifest = builder.getJar().getManifest();
 
         String bcp = manifest.getMainAttributes().getValue( Constants.BUNDLE_CLASSPATH );
@@ -326,8 +326,7 @@ public class BundlePluginTest extends AbstractBundlePluginTest
         instructions.put( DependencyEmbedder.EMBED_DEPENDENCY, "artifactId=a|b" );
         Properties props = new Properties();
 
-        DependencyNode dependencyGraph = plugin.buildDependencyGraph(project);
-        Builder builder = plugin.buildOSGiBundle( project, dependencyGraph, instructions, props, plugin.getClasspath( project, dependencyGraph ) );
+        Builder builder = plugin.buildOSGiBundle( project, instructions, plugin.getClasspath( project) );
         Manifest manifest = builder.getJar().getManifest();
 
         String bcp = manifest.getMainAttributes().getValue( Constants.BUNDLE_CLASSPATH );
@@ -353,17 +352,16 @@ public class BundlePluginTest extends AbstractBundlePluginTest
         MavenProject project = getMavenProjectStub();
         project.setDependencyArtifacts(artifacts);
         Properties props = new Properties();
-        DependencyNode dependencyGraph = plugin.buildDependencyGraph(project);
-        Jar[] classpath = plugin.getClasspath(project, dependencyGraph);
+        ClassPathItem[] classpath = plugin.getClasspath(project);
 
         Map instructions1 = new HashMap();
         instructions1.put( DependencyEmbedder.EMBED_DEPENDENCY, "!scope=compile" );
-        Builder builder1 = plugin.buildOSGiBundle( project, dependencyGraph, instructions1, props, classpath );
+        Builder builder1 = plugin.buildOSGiBundle( project, instructions1, classpath );
         Manifest manifest1 = builder1.getJar().getManifest();
 
         Map instructions2 = new HashMap();
         instructions2.put( DependencyEmbedder.EMBED_DEPENDENCY, "scope=!compile" );
-        Builder builder2 = plugin.buildOSGiBundle( project, dependencyGraph, instructions2, props, classpath );
+        Builder builder2 = plugin.buildOSGiBundle( project, instructions2, classpath );
         Manifest manifest2 = builder2.getJar().getManifest();
 
         String bcp1 = manifest1.getMainAttributes().getValue( Constants.BUNDLE_CLASSPATH );
@@ -381,12 +379,28 @@ public class BundlePluginTest extends AbstractBundlePluginTest
         assertEquals( eas1, eas2 );
     }
 
+    /**
+     * Test that no comment with a time stamp is added to the pom.properties file so ensure a reproducible build. Easiest way is
+     * to remove all comments.
+     */
+    public void testIgnoreTimestampInPomProperties() throws Exception
+    {
+        final MavenProject project = this.getMavenProjectStub();
+        final Map<String, String> instructions = new HashMap<>();
+
+        final Builder builder = this.plugin.buildOSGiBundle( project, instructions, this.plugin.getClasspath( project) );
+
+        final String path = "META-INF/maven/" + project.getGroupId() + "/" + project.getArtifactId() + "/pom.properties";
+        final Resource resource = builder.getJar().getResource(path);
+        final String fileContent = new String(resource.buffer().array(), StandardCharsets.ISO_8859_1);
+        assertThat(fileContent, not(containsString("#")));
+    }
 
     public void testPropertySanitizing() throws Exception
     {
         MavenProject project = getMavenProjectStub();
 
-        Properties props = new Properties();
+        Properties props = project.getProperties();
 
         props.put( new File( "A" ), new File( "B" ) );
         props.put( new int[4], new HashMap( 2 ) );
@@ -396,8 +410,7 @@ public class BundlePluginTest extends AbstractBundlePluginTest
         props.put( "4", new HashMap( 2 ) );
         props.put( "1, two, 3.0", new char[5] );
 
-        DependencyNode dependencyGraph = plugin.buildDependencyGraph(project);
-        Builder builder = plugin.getOSGiBuilder( project, new HashMap(), props, plugin.getClasspath( project, dependencyGraph ) );
+        Builder builder = plugin.getOSGiBuilder( project, new HashMap(), plugin.getClasspath( project) );
 
         File file = new File( getBasedir(), "target" + File.separatorChar + "test.props" );
         builder.getProperties().store( new FileOutputStream( file ), "TEST" );
